# Developer Guide

Developer-focused documentation.

## Architecture

Overview of the system architecture.

## Testing

How to run tests.

Setext heading style
====================

This section uses setext H1 style.

Setext subsection
-----------------

This uses setext H2 style.
